==> haskell-binary-tagged-0.3.1-285-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-tagged
version:              0.3.1
visibility:           public
id:                   binary-tagged-0.3.1-AruK6PaDqw8mYzASyN7w3
key:                  binary-tagged-0.3.1-AruK6PaDqw8mYzASyN7w3
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Tagged binary serialisation.
description:
    Structurally tag binary serialisation stream.

    Say you have:

    Say you have a data type

    @
    data Record = Record
    \  { _recordFields  :: HM.HashMap Text (Integer, ByteString)
    \  , _recordEnabled :: Bool
    \  }
    \  deriving (Eq, Show, Generic)

    instance @Binary@ Record
    instance '\''Structured'\'' Record
    @

    then you can serialise and deserialise @Record@ values with a structure tag by simply

    @
    '\''structuredEncode'\'' record :: LBS.ByteString
    '\''structuredDecode'\'' lbs    :: IO Record
    @

    If structure of @Record@ changes in between, deserialisation will fail early.

    The overhead is next to non-observable.

    @
    benchmarking encode/Binary
    time                 352.8 μs   (349.5 μs .. 355.9 μs)

    benchmarking encode/Tagged
    time                 350.8 μs   (349.0 μs .. 353.1 μs)

    benchmarking decode/Binary
    time                 346.8 μs   (344.7 μs .. 349.9 μs)

    benchmarking decode/Tagged
    time                 353.8 μs   (352.0 μs .. 355.8 μs)
    @

category:             Data
abi:                  f144b7dd8f59f0fb3e1f75ee1b9bed60
exposed:              True
exposed-modules:      Data.Binary.Tagged
import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-tagged-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-tagged-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-tagged-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-tagged
hs-libraries:         HSbinary-tagged-0.3.1-AruK6PaDqw8mYzASyN7w3
depends:
    array-0.5.4.0 base-4.17.2.1
    base16-bytestring-1.0.2.0-8KOr0OVfDkD2ATl4yj4Mhp binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    structured-0.1.1-K2xcr1LHywYIF6eAAcNZDW
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C

haddock-interfaces:
    /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock

haddock-html:         /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-tagged-0.3.1-286-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-tagged
version:              0.3.1
visibility:           public
id:                   binary-tagged-0.3.1-1ZBkVR4M25DJLvMH063q7O
key:                  binary-tagged-0.3.1-1ZBkVR4M25DJLvMH063q7O
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Tagged binary serialisation.
description:
    Structurally tag binary serialisation stream.

    Say you have:

    Say you have a data type

    @
    data Record = Record
    \  { _recordFields  :: HM.HashMap Text (Integer, ByteString)
    \  , _recordEnabled :: Bool
    \  }
    \  deriving (Eq, Show, Generic)

    instance @Binary@ Record
    instance '\''Structured'\'' Record
    @

    then you can serialise and deserialise @Record@ values with a structure tag by simply

    @
    '\''structuredEncode'\'' record :: LBS.ByteString
    '\''structuredDecode'\'' lbs    :: IO Record
    @

    If structure of @Record@ changes in between, deserialisation will fail early.

    The overhead is next to non-observable.

    @
    benchmarking encode/Binary
    time                 352.8 μs   (349.5 μs .. 355.9 μs)

    benchmarking encode/Tagged
    time                 350.8 μs   (349.0 μs .. 353.1 μs)

    benchmarking decode/Binary
    time                 346.8 μs   (344.7 μs .. 349.9 μs)

    benchmarking decode/Tagged
    time                 353.8 μs   (352.0 μs .. 355.8 μs)
    @

category:             Data
abi:                  b6cf0106c056cfe5be93cb21fd705daf
exposed:              True
exposed-modules:      Data.Binary.Tagged
import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-tagged-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-tagged-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-tagged-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-tagged
hs-libraries:         HSbinary-tagged-0.3.1-1ZBkVR4M25DJLvMH063q7O
depends:
    array-0.5.4.0 base-4.17.2.1
    base16-bytestring-1.0.2.0-FQGERq7xPf6LrZ8CrB0oGn binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    structured-0.1.1-CqdsMD93YMQ2PTxGt6wLSB
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C

haddock-interfaces:
    /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock

haddock-html:         /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
